@@ -1,6 +1,6 @@
-from PySide2.QtCore import QMargins, QSize, Signal, SignalInstance
-from PySide2.QtGui import QCloseEvent, QKeyEvent, QMouseEvent, Qt
-from PySide2.QtWidgets import (
+from PySide6.QtCore import QMargins, QSize, Signal, SignalInstance
+from PySide6.QtGui import QCloseEvent, QKeyEvent, QMouseEvent, Qt
+from PySide6.QtWidgets import (
     QComboBox,
     QDialog,
     QGridLayout,
@@ -249,7 +249,7 @@ class WorldMapLevelSelect(QScrollArea):
         self.setMouseTracking(True)
 
     def mouseMoveEvent(self, event: QMouseEvent):
-        x, y = self.world_view.mapFromParent(event.pos()).toTuple()
+        x, y = self.world_view.mapFromParent(event.position()).toTuple()
 
         x //= Block.WIDTH * 2
         y //= Block.HEIGHT * 2
@@ -283,7 +283,7 @@ class WorldMapLevelSelect(QScrollArea):
         return super(WorldMapLevelSelect, self).mouseMoveEvent(event)
 
     def mouseReleaseEvent(self, event: QMouseEvent):
-        x, y = self.world_view.mapFromParent(event.pos()).toTuple()
+        x, y = self.world_view.mapFromParent(event.position()).toTuple()
 
         x //= Block.WIDTH * 2
         y //= Block.HEIGHT * 2
