@@ -8,10 +8,9 @@ import subprocess
 import tempfile
 from typing import Tuple, Union
 
-from PySide2.QtCore import QSize
-from PySide2.QtGui import QCloseEvent, QKeySequence, QMouseEvent, Qt
-from PySide2.QtWidgets import (
-    QAction,
+from PySide6.QtCore import QSize
+from PySide6.QtGui import QAction, QCloseEvent, QKeySequence, QMouseEvent, QShortcut, Qt
+from PySide6.QtWidgets import (
     QDialog,
     QFileDialog,
     QHBoxLayout,
@@ -20,7 +19,6 @@ from PySide2.QtWidgets import (
     QMessageBox,
     QPushButton,
     QScrollArea,
-    QShortcut,
     QSizePolicy,
     QSplitter,
     QToolBar,
@@ -1253,7 +1251,7 @@ class MainWindow(QMainWindow):
 
     def mouseReleaseEvent(self, event: QMouseEvent):
         if event.button() == Qt.MiddleButton:
-            pos = self.level_view.mapFromGlobal(self.mapToGlobal(event.pos())).toTuple()
+            pos = self.level_view.mapFromGlobal(self.mapToGlobal(event.position())).toTuple()
 
             self.place_object_from_dropdown(pos)
 
